@@ -27,6 +27,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 from .materialization import to_awk
 from .file_peeking import get_structure
+from .dataset_resolver import ds_type_resolver
 
-__version__ = "1.1.0"
-__all__ = ["to_awk", "get_structure"]
+__version__ = "1.2.0"
+__all__ = ["to_awk", "get_structure", "ds_type_resolver"]
